@@ -1,4 +1,4 @@
-# $Id: install.py 893 2014-03-13 04:24:14Z mwall $
+# $Id: install.py 1295 2015-03-23 21:45:34Z mwall $
 # installer for seg
 # Copyright 2014 Matthew Wall
 
@@ -10,7 +10,7 @@ def loader():
 class SEGInstaller(ExtensionInstaller):
     def __init__(self):
         super(SEGInstaller, self).__init__(
-            version="0.2",
+            version="0.5",
             name='seg',
             description='Upload weather data to SmartEnergyGroups.',
             author="Matthew Wall",
@@ -20,6 +20,6 @@ class SEGInstaller(ExtensionInstaller):
                 'StdRESTful' : {
                     'SmartEnergyGroups': {
                         'token': 'INSERT_TOKEN_HERE',
-                        'station': 'INSERT_STATION_IDENTIFIER_HERE'}}},
+                        'node': 'INSERT_STATION_IDENTIFIER_HERE'}}},
             files=[('bin/user', ['bin/user/seg.py'])]
             )
